@@ -230,6 +230,8 @@ Examples of use:
                             dest='stdout_csv', help='display stats to stdout, csv format (comma separated list of plugins/plugins.attribute)')
         parser.add_argument('--issue', default=None, action='store_true',
                             dest='stdout_issue', help='test all plugins and exit (please copy/paste the output if you open an issue)')
+        parser.add_argument('--api-doc', default=None, action='store_true',
+                            dest='stdout_apidoc', help='display fields descriptions')
         if not WINDOWS:
             parser.add_argument('--hide-kernel-threads', action='store_true', default=False,
                                 dest='no_kernel_threads', help='hide kernel threads in process list (not available on Windows)')
