@@ -264,8 +264,8 @@ class GlancesProcesses(object):
 
         # Grab standard stats
         #####################
-        sorted_attrs = ['cpu_percent', 'cpu_times', 
-                          'memory_percent', 'name', 
+        sorted_attrs = ['cpu_percent', 'cpu_times',
+                          'memory_percent', 'name',
                           'status', 'status', 'num_threads']
         displayed_attr = ['memory_info', 'nice', 'pid', 'ppid']
         cached_attrs = ['cmdline', 'username']
@@ -363,6 +363,9 @@ class GlancesProcesses(object):
             first = False
             # /End of extended stats
 
+            # PID is the key
+            proc['key'] = 'pid'
+
             # Time since last update (for disk_io rate computation)
             proc['time_since_update'] = time_since_update
 
